SCRIPT_DEPENDENCIES = {
    "cal": [
        "anthropic",
        "google-auth-oauthlib",
        "google-auth",
        "google-api-python-client",
        "pytz",
        "tzlocal",
        "rich",
    ],
    "make-obsidian-plugin": ["rich", "inquirer"],
    "do": ["pynput"],
    "convert": ["open-interpreter", "anthropic>=0.37.1,<0.38.0"],
    "transcribe": [
        "pyaudio",
        "wave",
        "pydub",
        "rich",
        "ollama",
        "pydantic",
        "openai>=1.12.0",
    ],
    "prioritize": [
        "pyaudio",
        "wave",
        "pydub",
        "rich",
        "ollama",
        "pydantic",
        "openai>=1.12.0",
    ],
    "log": [],
}
